<?php
use SendGrid\Mail\Attachment;
require __DIR__.'/../datos/Conexion.clase.php';
require_once __DIR__.'/../util/definiciones.php';
require_once __DIR__.'/../util/sendgrid-php/vendor/autoload.php';
date_default_timezone_set("America/Lima");

class ProveedorEmpresa extends Conexion {

    public function listarManoObra($codigoConductor)
    {
        try{
            $sql = "SELECT DISTINCT
                        pe.codigo_empresa as cod_emp
                    FROM
                        proveedor_empresa as pe inner join vehiculo as ve on(pe.codigo_vehiculo = ve.codigo_vehiculo)
                        inner join conductor_control as c on(pe.codigo_conductor = c.codigo_conductor)
                        inner join tipo_vehiculo_control as tv on(ve.codigo_tipo_vehiculo = tv.codigo_tipo_vehiculo)
                        inner join proveedor as p on(pe.codigo_proveedor = p.codigo_proveedor)
                        inner join ruta_transporte as r on(pe.codigo_ruta_transporte = r.codigo_ruta_transporte)
                        inner join categoria_personal_fundo as tp on(c.codigo_tipo_personal = tp.codigo_categoria_personal)
                        inner join empresa_control as e on(pe.codigo_empresa = e.codigo_empresa)
                    WHERE c.codigo_conductor = ? ";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();
            $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
            $respuesta = [];
            foreach($resultado as $item){
                $sql = "SELECT
                            tmo.nombre as man_obra,
                            etm.codigo_tipo_mano_obra,
                            etm.estado,
                            etm.codigo_empresa
                        from
                            empresa_tipo_mano_obra as etm inner join tipo_mano_obra as tmo on(etm.codigo_tipo_mano_obra = tmo.codigo_tipo_mano_obra)
                        where
                            etm.codigo_empresa = ?";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->bindParam(1, $item["cod_emp"]);
                $sentencia->execute();
                if($sentencia->rowCount()){
                    $manoObra = $sentencia->fetchAll(PDO::FETCH_ASSOC);
                    $respuesta[] = $manoObra;
                }
            }

            return $respuesta;
        }catch(Exception $e){
            throw $e;
        }
    }
    public function listarPersonal($codigoConductor)
    {
        try{
            $sql = "SELECT DISTINCT
                        pe.codigo_empresa as cod_emp
                    FROM
                        proveedor_empresa as pe inner join vehiculo as ve on(pe.codigo_vehiculo = ve.codigo_vehiculo)
                        inner join conductor_control as c on(pe.codigo_conductor = c.codigo_conductor)
                        inner join tipo_vehiculo_control as tv on(ve.codigo_tipo_vehiculo = tv.codigo_tipo_vehiculo)
                        inner join proveedor as p on(pe.codigo_proveedor = p.codigo_proveedor)
                        inner join ruta_transporte as r on(pe.codigo_ruta_transporte = r.codigo_ruta_transporte)
                        inner join categoria_personal_fundo as tp on(c.codigo_tipo_personal = tp.codigo_categoria_personal)
                        inner join empresa_control as e on(pe.codigo_empresa = e.codigo_empresa)
                    WHERE c.codigo_conductor = ? ";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();
            $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
            $respuesta = [];
            foreach($resultado as $item){
                $sql = "SELECT
                            e.codigo_empleado as codigo,
                            e.numero_documento as dni,
                            e.nombre,
                            e.apellido_paterno as paterno,
                            e.apellido_materno as materno,
                            ee.estado,
                            'S' as sincronizado,
                            e.codigo_off_line
                        from
                            empleado as e inner join empleado_empresa as ee on(e.codigo_empleado = ee.codigo_empleado)
                        where
                            ee.codigo_empresa = ?;";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->bindParam(1, $item["cod_emp"]);
                $sentencia->execute();
                if($sentencia->rowCount()){
                    $personal = $sentencia->fetchAll(PDO::FETCH_ASSOC);
                    $respuesta[] = $personal;
                }
            }

            return $respuesta;
        }catch(Exception $e){
            throw $e;
        }
    }
    public function buscarViajes($codigoProveedorEmpresa){
        $sql = "SELECT * from viaje where codigo_proveedor_empresa = ? order by fecha_registro_dispositivo desc limit 1;";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $codigoProveedorEmpresa);
        $sentencia->execute();
        $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
        return $resultado;
    }

    public function generarNuevoViaje($codigoProveedorEmpresa){
        $sql = "SELECT * from proveedor_empresa where codigo_proveedor_empresa = ?;";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $codigoProveedorEmpresa);
        $sentencia->execute();
        $proveedorEmpresa = $sentencia->fetch(PDO::FETCH_ASSOC);
        $codigoProveedor = $proveedorEmpresa["codigo_proveedor"];
        $codigoEmpresa = $proveedorEmpresa["codigo_empresa"];
        $codigoConductor = $proveedorEmpresa["codigo_conductor"];
        $codigoVehiculo = $proveedorEmpresa["codigo_vehiculo"];
        $codigoRutaTransporte = $proveedorEmpresa["codigo_ruta_transporte"];

        $sql = "SELECT numero + 1 as nc from correlativo_control where tabla = 'viaje';";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->execute();

        if (!$sentencia->rowCount()) {
            $sql = "INSERT into correlativo_control(numero, tabla) values(0, 'viaje');";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();
            $codigoViaje = 1;
        } else {
            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
            $codigoViaje = $resultado["nc"];
        }

        $sql = "INSERT into viaje(codigo_viaje, tipo_viaje, codigo_proveedor_empresa, codigo_proveedor, codigo_empresa, codigo_conductor, codigo_vehiculo, codigo_ruta_transporte, fecha_registro, estado)
                            values(:codigo_viaje, :tipo_viaje, :codigo_proveedor_empresa, :codigo_proveedor, :codigo_empresa, :codigo_conductor, :codigo_vehiculo, :codigo_ruta_transporte, :fecha_registro, :estado);";
        $timeStamp = date('Y-m-d H:i:s');
        $estado = 'A';
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(":codigo_viaje", $codigoViaje);
        $sentencia->bindParam(":tipo_viaje", 'I');
        $sentencia->bindParam(":codigo_proveedor_empresa", $codigoProveedorEmpresa);
        $sentencia->bindParam(":codigo_proveedor", $codigoProveedor);
        $sentencia->bindParam(":codigo_empresa", $codigoEmpresa);
        $sentencia->bindParam(":codigo_conductor", $codigoConductor);
        $sentencia->bindParam(":codigo_vehiculo", $codigoVehiculo);
        $sentencia->bindParam(":codigo_ruta_transporte", $codigoRutaTransporte);
        $sentencia->bindParam(":fecha_registro", $timeStamp);
        $sentencia->bindParam(":estado", $estado);
        $sentencia->execute();

        $resultado["codigo_viaje"] = $codigoViaje;
        $resultado["codigo_viaje"] = $codigoViaje;
        $resultado["codigo_viaje"] = $codigoViaje;
        $resultado["codigo_viaje"] = $codigoViaje;
        $resultado["codigo_viaje"] = $codigoViaje;
        $resultado["codigo_viaje"] = $codigoViaje;
    }

    public function listarTarjetasQR($codigoConductor){
        $sql = "SELECT
                    p.ruc,
                    e.abreviatura as nombre_empresa,
                    p.razon_social,
                    r.nombre_ruta,
                    r.precio_ruta,
                    c.estado_conductor,
                    ve.estado as ve_est,
                    pe.codigo_conductor as cod_cond,
                    pe.codigo_vehiculo as cod_ve,
                    pe.codigo_proveedor as cod_pro,
                    pe.codigo_empresa as cod_emp,
                    pe.codigo_ruta_transporte as cod_rut,
                    pe.codigo_proveedor_empresa as cod_prov_emp,
                    coalesce(pe.correo, '') as correo,
                    REPLACE(ENCODE(CONVERT_TO(
                        (
                        've_cod=' || pe.codigo_vehiculo ||
                        '#ve_pla=' || ve.placa ||
                        '#ve_mar=' || ve.marca ||
                        '#ve_mod=' || ve.modelo ||
                        '#ve_cap=' || ve.capacidad ||
                        '#ve_cod_tv=' || ve.codigo_tipo_vehiculo ||
                        '#cond_cod_tp=2' ||
                        '#emp_cod=' || pe.codigo_empresa ||
                        '#prov_cod=' || pe.codigo_proveedor ||
                        '#prov_raz_soc=' || p.razon_social ||
                        '#prov_ruc=' || p.ruc ||
                        '#cond_cod=' || pe.codigo_conductor ||
                        '#cond_nomb=' || (case (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) when ' , ' then 'NOMBRE NO REGISTRADO' else (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) end) ||
                        '#cond_lic=' || (case coalesce(c.numero_licencia, 'NO REGISTRADA') when '' then 'NO REGISTRADA' else coalesce(c.numero_licencia, 'NO REGISTRADA') end) ||
                        '#rut_cod=' || pe.codigo_ruta_transporte ||
                        '#rut_nomb=' || r.nombre_ruta ||
                        '#dni=' || c.dni_conductor ||
                        '#empresa=' || e.abreviatura ||
                        '#ve_tipo=' || tv.descripcion_tipo_vehiculo
                        ),
                        'UTF-8'), 'BASE64'),'\n','') as qr_transportista,
                    (case pe.estado when 'A' then 'ACTIVO' else 'INACTIVA' end) as estado,
                    ve.placa,
                    ve.marca,
                    ve.modelo,
                    ve.codigo_tipo_vehiculo,
                    ve.fecha_soat_vencimiento,
                    ve.fecha_revision,
                    ve.fecha_revision_vencimiento,
                    (case when coalesce(ve.fecha_soat_vencimiento, current_date) <= current_date then (to_char(coalesce(ve.fecha_soat_vencimiento, current_date), 'DD/MM/YYYY') || '</br>CADUCADO') else to_char(ve.fecha_soat_vencimiento, 'DD/MM/YYYY') end) as venc_soat,
                    (case when coalesce(ve.fecha_revision_vencimiento, current_date) <= current_date then (to_char(coalesce(ve.fecha_revision_vencimiento, current_date), 'DD/MM/YYYY') || '</br>CADUCADA') else to_char(ve.fecha_revision_vencimiento, 'DD/MM/YYYY') end) as ven_rev,
                    tv.descripcion_tipo_vehiculo as tip_ve,
                    c.dni_conductor as dni,
                    (case (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) when ' , ' then 'NOMBRE NO REGISTRADO' else (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) end) as conductor,
                    c.apellidos_paternos_conductor as pat,
                    c.apellidos_maternos_conductor as mat,
                    c.nombre_conductor as nomb,
                    c.nacionalidad,
                    c.numero_licencia,
                    coalesce(c.categoria_licencia, '-1') as categoria_licencia,
                    c.fecha_vencimiento_licencia,
                    (case coalesce(c.numero_licencia, 'NO REGISTRADA') when '' then 'NO REGISTRADA' else coalesce(c.numero_licencia, 'NO REGISTRADA') end) as licencia,
                    (case when coalesce(c.fecha_vencimiento_licencia, current_date) <= current_date then (to_char(coalesce(c.fecha_vencimiento_licencia, current_date), 'DD/MM/YYYY') || '</br>CADUCADA') else to_char(c.fecha_vencimiento_licencia, 'DD/MM/YYYY') end) as licencia_venc
                FROM
                    proveedor_empresa as pe inner join vehiculo as ve on(pe.codigo_vehiculo = ve.codigo_vehiculo)
                    inner join conductor_control as c on(pe.codigo_conductor = c.codigo_conductor)
                    inner join tipo_vehiculo_control as tv on(ve.codigo_tipo_vehiculo = tv.codigo_tipo_vehiculo)
                    inner join proveedor as p on(pe.codigo_proveedor = p.codigo_proveedor)
                    inner join ruta_transporte as r on(pe.codigo_ruta_transporte = r.codigo_ruta_transporte)
                    inner join categoria_personal_fundo as tp on(c.codigo_tipo_personal = tp.codigo_categoria_personal)
                    inner join empresa_control as e on(pe.codigo_empresa = e.codigo_empresa)
                WHERE c.codigo_conductor = ?
                ORDER BY
                    5, 13, 11, 6 asc";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $codigoConductor);
        $sentencia->execute();
        $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
        $respuesta = [];
        foreach($resultado as $item){
            if(POSTGRES_DB == 'proolmos_bd_dev_test'){
                $logo_empresa = "https://movil.dev.proolmos.pe/images/logo_empresa/".$item["cod_emp"].".png";
            }else{
                $logo_empresa = "https://movil.proolmos.pe/images/logo_empresa/".$item["cod_emp"].".png";
            }

            $ruta_foto = "../images/logo_empresa/".$item["cod_emp"].".png";
            if(!file_exists($ruta_foto)){
                if(POSTGRES_DB == 'proolmos_bd_dev_test'){
                    $logo_empresa = "https://movil.dev.proolmos.pe/images/logo-color.png";
                }else{
                    $logo_empresa = "https://movil.proolmos.pe/images/logo-color.png";
                }

            }
            $item["foto_empresa"] = $logo_empresa;
            $sql = "SELECT * from viaje where codigo_proveedor_empresa = ?;";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();
            $viajes = $sentencia->fetchAll(PDO::FETCH_ASSOC);
            $item["viajes"] = $viajes;
            $respuesta[] = $item;
        }

        return $respuesta;
    }

    public function obtenerProveedorEmpresa($codigo_empresa){
        $sql = "SELECT * from proveedor_empresa where codigo_empresa = ?";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $codigo_empresa);
        $sentencia->execute();
        return $sentencia->fetchAll(PDO::FETCH_ASSOC);
    }

    public function loginMovil($documento, $clave)
    {
        $sql = "SELECT
                    (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) as nombre_conductor,
                    c.apellidos_paternos_conductor as paterno,
                    c.apellidos_maternos_conductor as materno,
                    c.nombre_conductor as nombre,
                    uc.estado,
                    uc.verificado,
                    uc.telefono,
                    uc.correo,
                    uc.codigo_conductor
                FROM
                    conductor_control as c inner join usuario_conductor as uc on(c.codigo_conductor = uc.codigo_conductor)
                WHERE
                    trim(uc.documento) = ? and uc.clave = ?";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $documento);
        $sentencia->bindParam(2, $clave);
        $sentencia->execute();
        if(!$sentencia->rowCount()){
            throw new Exception("Credenciales incorrectas");
        }
        $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
        if($resultado["estado"] != "A"){
            throw new Exception("Tu usuario está inactivo.");
        }
        return $resultado;
    }

    public function buscarConductor($dni){
        try {
            $sql = "SELECT
                        c.codigo_conductor,
                        (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) as nombre_conductor,
                        pe.estado,
                        $dni as dni
                    from
                        proveedor_empresa as pe inner join conductor_control as c on(pe.codigo_conductor = c.codigo_conductor)
                    where
                        c.dni_conductor = ? and pe.estado='A'
                    order by pe.fecha_registro desc limit 1;";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $dni);
            $sentencia->execute();
            if(!$sentencia->rowCount()){
                throw new Exception("No estás registrado en ninguna empresa dentro de la irrigación Olmos o tu cuenta está inactiva.");
            }

            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
            $sql = "SELECT
                        *
                    FROM
                        usuario_conductor
                    WHERE
                        codigo_conductor = ?";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $resultado["codigo_conductor"]);
            $sentencia->execute();
            if($sentencia->rowCount()){
                $usuario = $sentencia->fetch(PDO::FETCH_ASSOC);
                if($usuario["estado"] != "A"){
                    throw new Exception("Tu usuario se encuentra inactivo, por favor comunícate con tu administrador");
                }
                if($usuario["verificado"] == "N"){
                    $resultado["verificar"] = true;
                    $resultado["telefono"] = $usuario["telefono"];
                    $resultado["correo"] = $usuario["correo"];
                }
                if($usuario["verificado"] == "S"){
                    $resultado["login"] = true;
                }
            }
            return $resultado;
        }catch(Exception $e){
            throw $e;
        }
    }

    public function verificarCuenta($codigoConductor, $codigoVerificacion)
    {
        // $this->dblink->beginTransaction();
        try{
            $sql = "SELECT * from usuario_conductor where codigo_conductor = ?";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();
            $usuario = $sentencia->fetch(PDO::FETCH_ASSOC);

            if($usuario["codigo_verificacion"] != $codigoVerificacion){
                throw new Exception("El código ingresado no corresponde.");
            }

            $sql = "UPDATE
                        usuario_conductor
                    set
                        verificado = 'S'
                    where
                        codigo_conductor = ?";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();

            return "Su cuenta ha sido verificada.";
        }catch(Exception $e){
            // $this->dblink->rollBack();
            throw $e;
        }
    }

    public function recuperarCuenta($numeroDocumento)
    {
        try{
            $sql = "SELECT * from usuario_conductor where trim(documento) = ?";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $numeroDocumento);
            $sentencia->execute();
            $usuario = $sentencia->fetch(PDO::FETCH_ASSOC);

            if(!$sentencia->rowCount()){
                throw new Exception("No se encontró tu usuario.");
            }
            $telefono = $usuario["telefono"];
            $telefono = $usuario["telefono"];
            $codigoVerificacion = "";
            if($usuario["verificado"] == "N"){
                $codigoVerificacion = "Cod. verificación: ".$usuario["codigo_verificacion"];
            }
            $clave = $this->randomString(6);
            $md5Clave = md5($clave);

            $sql = "UPDATE
                        usuario_conductor
                    set
                        clave = ?
                    where
                        trim(documento) = ?";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $md5Clave);
            $sentencia->bindParam(2, $numeroDocumento);
            $sentencia->execute();

            $mensaje = utf8_decode("Usuario: $numeroDocumento Clave: $clave  $codigoVerificacion - Credenciales Pro Olmos");
            $this->enviarSms($telefono, $mensaje);
            return "Genial, hemos enviado tus credenciales a tu teléfono.";
        }catch(Exception $e){
            throw $e;
        }
    }

    public function nuevaCuenta($codigoConductor, $telefono, $correo)
    {
        $this->dblink->beginTransaction();
        try{
            $sql = "SELECT
                        c.codigo_conductor,
                        (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) as nombre_conductor,
                        pe.estado,
                        c.dni_conductor as dni
                    from
                        proveedor_empresa as pe inner join conductor_control as c on(pe.codigo_conductor = c.codigo_conductor)
                    where
                        c.codigo_conductor = ? and pe.estado='A'
                    order by pe.fecha_registro desc limit 1;";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();
            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);

            $clave = $this->randomString(6);
            $codigoVerificacion = $this->randomString(6);
            $md5Clave = md5($clave);
            $persona = $resultado["nombre_conductor"];
            $dni = $resultado["dni"];


            $sql = "SELECT * from usuario_conductor where codigo_conductor = ?";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigoConductor);
            $sentencia->execute();

            if(!$sentencia->rowCount()){
                $mensaje = "Hola $persona, hemos identificado que eres un usuario nuevo. <b>¡Bienvenido al Sistema de Control Vehicular de la Irrigación Olmos!</b>
                    <br> Con estas credenciales podrás verificar tu cuenta al iniciar sesión en la aplicación.";

                $sql = "INSERT into usuario_conductor
                        (codigo_conductor, clave, codigo_verificacion, correo, telefono, documento)
                        values
                        (?, ?, ?, ?, ?, ?);";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->bindParam(1, $codigoConductor);
                $sentencia->bindParam(2, $md5Clave);
                $sentencia->bindParam(3, $codigoVerificacion);
                $sentencia->bindParam(4, $correo);
                $sentencia->bindParam(5, $telefono);
                $sentencia->bindParam(6, $dni);
                $sentencia->execute();
            }else{
                $usuario = $sentencia->fetch(PDO::FETCH_ASSOC);
                $telefono = empty($usuario["telefono"]) ? '' : $usuario["telefono"];
                $correo = empty($usuario["correo"]) ? '' : $usuario["correo"];
                $mensaje = "Hola $persona, hemos identificado que eres un usuario nuevo. <b>¡Bienvenido al Sistema de Control Vehicular de la Irrigación Olmos!</b>
                    <br> Con estas credenciales podrás verificar tu cuenta al iniciar sesión en la aplicación.";
                $clave = "";
                $sql = "UPDATE
                            usuario_conductor
                        set
                            codigo_verificacion = ?
                        where
                            codigo_conductor = ?";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->bindParam(1, $codigoVerificacion);
                $sentencia->bindParam(2, $codigoConductor);
                $sentencia->execute();
                $mensaje = "Hola $persona, <b> has solicitado un nuevo código de verificación</b>
                    <br> Con estas credenciales podrás verificar tu cuenta al iniciar sesión en la aplicación.";
            }

            if(!empty($correo)){
                $this->enviarCorreoCredencialesLogin($dni, $mensaje, $correo, $clave, $codigoVerificacion);
            }

            if(!empty($telefono)){
                $mensaje = utf8_decode("Usuario: $dni Clave: $clave  Cod. verificación: $codigoVerificacion - Credenciales Pro Olmos");
                if(empty($clave)){
                    $mensaje = utf8_decode("Ingrese $codigoVerificacion para verificar los datos de tu cuenta Pro Olmos!");
                }
                $this->enviarSms($telefono, $mensaje);
            }

            $this->dblink->commit();
            return "Sus credenciales han sido enviadas al correo/teléfono indicado";
        }catch(Exception $e){
            $this->dblink->rollBack();
            throw $e;
        }
    }

    public function enviarCorreoCredencialesLogin($documento, $mensaje, $correo, $clave, $codigoVerificacion)
    {
        try{
            $innerHTML = '
                            <div
                                style="color:#807b7b;font-family:Roboto, Tahoma, Verdana, Segoe, sans-serif;line-height:1.5;padding-top:0px;padding-right:10px;padding-bottom:10px;padding-left:10px;">
                                <div
                                    style="font-size: 14px; line-height: 1.5; color: #807b7b; font-family: Roboto, Tahoma, Verdana, Segoe, sans-serif; mso-line-height-alt: 21px;">

                                    <p
                                        style="font-size: 18px; line-height: 1.5; word-break: break-word; text-align: center; mso-line-height-alt: 27px; margin: 0;">
                                        <b>CREDENCIALES DE INICIO DE SESIÓN PARA EL APLICATIVO MÓVIL</b>
                                        <br>
                                        <br>
                                        <b>Usuario: </b> '.$documento;
            if(!empty($clave)){
                $innerHTML .= '
                                        <br>
                                        <b>Clave: </b> '.$clave;
            }
            $innerHTML .= '
                                        <br>
                                        <b>Código verificación: </b> '.$codigoVerificacion.'
                                    </p>
                                    <br>
                                    <br>
                                    <p
                                        style="font-size: 18px; line-height: 1.5; word-break: break-word; text-align: center; mso-line-height-alt: 27px; margin: 0;">
                                        <span style="font-size: 18px;"> Este es un mensaje generado por el equipo de tecnología de
                                            Pro Olmos, por favor no respondas a este correo.</span>

                                        <br>
                                        <br>
                                        <a target="_blank"
                                            href="link:aplicaciónandroid"
                                            style="text-decoration: none;cursor: pointer;background: #019C50; border: 0; padding-left: 4.2rem; padding-right: 4.2rem; padding-top: 1rem;
                                                                        padding-bottom: 1rem; border-radius: 1rem; font-size: 18px; line-height: 1.5; color: #ffffff; font-family: Roboto, Tahoma,
                                                                        Verdana, Segoe, sans-serif; mso-line-height-alt: 21px;">
                                                                        INICIAR SESIÓN
                                                                        </a>
                                    </p>
                                </div>
                            </div>
                        ';
            $htmlFile = __DIR__ . '/../plantilla/correo/plantilla_primary.html';
            $html = file_get_contents($htmlFile);
            $html = str_replace("{{Mensaje}}", $mensaje, $html);
            $html = str_replace("{{inner_html}}", $innerHTML, $html);
            $email = new \SendGrid\Mail\Mail();
            $email->setFrom("area.sistemas@proolmos.pe", "Pro Olmos");
            $email->setSubject("Credenciales Pro Olmos - Conductor");
            $email->addTo($correo);
            $email->addContent(
                "text/html",
                $html
                );
            $sendgrid = new \SendGrid(SENDGRID_API_KEY);
            $response = $sendgrid->send($email);
        }catch(Exception $e){
            throw $e;
        }
    }

    function enviarSms($telefono, $mensaje){
        $url_holder_sms = str_replace(' ', '%20', "http://servicio.smsmasivos.com.ar/enviar_sms.asp?api=1&usuario=PROOLMOS&clave=PROOLMOS352&tos=" . $telefono . "&texto=" . $mensaje);
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url_holder_sms);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        $data = curl_exec($ch);
        curl_close($ch);
    }

    function randomString( $length )
    {
        $chars = "0123456789";
        // $chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
        return substr(str_shuffle($chars),0,$length);
    }
}