<?php
require __DIR__.'/../datos/Conexion.clase.php';
require __DIR__ . '/../util/definiciones.php';
require_once __DIR__ . '/../util/sendgrid-php/vendor/autoload.php';
date_default_timezone_set("America/Lima");


class Cron extends Conexion {

    public function reporteAforoEntrada(){
        try {
            $fecha_ayer = date('Y-m-d',strtotime("-1 days"));
            $sql = "SELECT
                        g.codigo_entrada_salida as cod,
                        g.placa_entrada_salida as placa,
                        g.hora_entrada_salida as hor,
                        e.nombre_empresa as emp,
                        g.dni_conductor as dni,
                        g.nombre_conductor as nomb,
                        (select pc.email_personal from personal_control as pc inner join usuario_control as uc on(pc.dni_personal = uc.dni_usuario) where uc.codigo_usuario = g.codigo_usuario) as usu,
                        (select c.descripcion_caseta from caseta_control as c where c.codigo_caseta = g.codigo_caseta) as caseta
                    FROM
                        garita_entrada_salida_control as g inner join empresa_control as e on(g.codigo_empresa = e.codigo_empresa)
                    WHERE
                        g.aforo = 'N' and g.tipo = 'E' and g.estado_entrada = 'E' and g.fecha_entrada_salida = :fecha_ayer
                    ORDER BY
                        g.codigo_caseta asc, g.fecha_entrada_salida asc, g.hora_entrada_salida asc";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(":fecha_ayer", $fecha_ayer);
            $sentencia->execute();

            if ($sentencia->rowCount()) {
                $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
                $htmlInner = "";
                //DETALLE
                foreach($resultado as $entrada){
                    $cod = $entrada["cod"];
                    $placa = $entrada["placa"];
                    $hor = $entrada["hor"];
                    $emp = $entrada["emp"];
                    $dni = $entrada["dni"];
                    $nomb = $entrada["nomb"];
                    $usu = $entrada["usu"];
                    $caseta = $entrada["caseta"];
                    $htmlInnerFile = __DIR__ . '/../plantilla/correo/plantilla_reporte_inner.html';
                    $innerHtml = file_get_contents($htmlInnerFile);
                    $innerHtml = str_replace("{{empresa}}", $emp, $innerHtml);
                    $innerHtml = str_replace("{{garita}}", $caseta, $innerHtml);
                    $innerHtml = str_replace("{{hora}}", $hor, $innerHtml);
                    $innerHtml = str_replace("{{placa}}", $placa, $innerHtml);
                    $innerHtml = str_replace("{{conductor}}", $nomb ." - ".$dni, $innerHtml);
                    $innerHtml = str_replace("{{usuario}}", $usu, $innerHtml);
                    $innerHtml = str_replace("{{codigo}}", $cod, $innerHtml);
                    $htmlInner .= $innerHtml;
                }
                //DETALLE
                $fecha_ayer = date('d/m/Y', strtotime("-1 days"));
                $mensaje = "Reporte de incumplimiento de capacidad vehicular del $fecha_ayer permitido según normativa del estado (Máximo 50% de la capacidad vehicular).";
                $htmlFile = __DIR__ . '/../plantilla/correo/plantilla_reporte_error.html';
                $html = file_get_contents($htmlFile);
                $html = str_replace("{{Mensaje}}", $mensaje, $html);
                $html = str_replace("{{inner_html}}", $htmlInner, $html);

                $email = new \SendGrid\Mail\Mail();
                $email->setFrom("area.sistemas@proolmos.pe", "Pro Olmos");
                $email->setSubject("Reporte incumplimiento de capacidad vehicular");
                $email->addTo("jchancafe@proolmos.pe");
                $email->addCc("rvasquez@proolmos.pe");
                $email->addContent(
                    "text/html",
                    $html
                );
                $sendgrid = new \SendGrid(SENDGRID_API_KEY);
                try {
                    $sendgrid->send($email);
                } catch (Exception $e) {
                    throw $e;
                }

                //Enviar mensaje de texto
                $telefono = "‭984943831‬";
                $fecha_servidor = date("d/m/Y") . ' ' . date("H:i:s");
                $mensaje = "Se ha enviado un correo con las infracciones de capacidad vehicular del dia de ayer ($fecha_ayer).";

                $url_holder_sms = str_replace(' ', '%20', "http://servicio.smsmasivos.com.ar/enviar_sms.asp?api=1&usuario=PROOLMOS&clave=PROOLMOS352&tos=" . $telefono . "&texto=" . $mensaje);
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $url_holder_sms);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
                $data = curl_exec($ch);
                curl_close($ch);
                //Enviar mensaje de texto
                return $resultado;
            }
        } catch (Exception $e) {
            throw $e;
        }
    }

    public function verificacionEntradasRapidas(){
        $this->dblink->beginTransaction();
        try{
            $fecha_ayer = date('Y-m-d', strtotime("-1 days"));
            $sql = "SELECT * from monitor_rapido as m inner join garita_entrada_salida_control as g on(m.codigo_entrada_salida = g.codigo_entrada_salida) where m.revision = 'S' and g.fecha_entrada_salida = :fecha_ayer";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(":fecha_ayer", $fecha_ayer);
            $sentencia->execute();

            if ($sentencia->rowCount()) {
                $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
                $htmlInner = "";
                //DETALLE
                foreach($resultado as $entrada){
                    $dni = $entrada["dni_conductor"];
                    $codigo_ruta_caseta_principal = $entrada["codigo_ruta"];

                    $htmlInnerFile = __DIR__ . '/../plantilla/correo/plantilla_reporte_row.html';
                    $innerHtml = file_get_contents($htmlInnerFile);
                    $innerHtml = str_replace("{{label_color}}", "C22E21", $innerHtml);
                    $innerHtml = str_replace("{{label_size}}", "20", $innerHtml);
                    $innerHtml = str_replace("{{label}}", "REGISTRO POR VERIFICAR", $innerHtml);
                    $innerHtml = str_replace("{{label_descripcion_size}}", "14", $innerHtml);
                    $innerHtml = str_replace("{{label_descripcion_color}}", "999999", $innerHtml);
                    $innerHtml = str_replace("{{label_descripcion}}", json_encode($entrada), $innerHtml);
                    $htmlInner .= $innerHtml;

                    $fecha_ayer = date('Y-m-d', strtotime("-1 days"));
                    $sql = "SELECT * from fundo_entrada_control where dni_conductor = :dni_conductor and (fecha_manual = :fecha_ayer or fecha_entrada_fundo = :fecha_ayer) and entrada_salida_fundo = 'E'";
                    $sentencia = $this->dblink->prepare($sql);
                    $sentencia->bindParam(":dni_conductor", $dni);
                    $sentencia->bindParam(":fecha_ayer", $fecha_ayer);
                    $sentencia->execute();

                    $numero_filas = $sentencia->rowCount();
                    $solucion = "";
                    if ($numero_filas) {
                        if($numero_filas > 1){
                            $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
                            $solucion = json_encode($resultado);
                        }else{
                            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);

                        }
                    }else{

                    }
                }

                //DETALLE
                $fecha_ayer = date('d/m/Y', strtotime("-1 days"));
                $mensaje = "Reporte de verificación del monitor rápido de entradas y salidas de la fecha \"$fecha_ayer\". <br> La Siguiente es una lista de las entradas por verificar.";
                $htmlFile = __DIR__ . '/../plantilla/correo/plantilla_reporte_error.html';
                $html = file_get_contents($htmlFile);
                $html = str_replace("{{Mensaje}}", $mensaje, $html);
                $html = str_replace("{{inner_html}}", $htmlInner, $html);

                $email = new \SendGrid\Mail\Mail();
                $email->setFrom("area.sistemas@proolmos.pe", "Pro Olmos");
                $email->setSubject("Reporte monitor rápido");
                $email->addTo("jchancafe@proolmos.pe");
                $email->addCc("rvasquez@proolmos.pe");
                $email->addContent(
                    "text/html",
                    $html
                );
                $sendgrid = new \SendGrid(SENDGRID_API_KEY);
                try {
                    $sendgrid->send($email);
                } catch (Exception $e) {
                    throw $e;
                }

                //Enviar mensaje de texto
                // $telefono = "969105301";
                // $fecha_servidor = date("d/m/Y") . ' ' . date("H:i:s");
                // $mensaje = "Se ha enviado un correo con las infracciones de capacidad vehicular del dia de ayer ($fecha_ayer).";

                // $url_holder_sms = str_replace(' ', '%20', "http://servicio.smsmasivos.com.ar/enviar_sms.asp?api=1&usuario=PROOLMOS&clave=PROOLMOS352&tos=" . $telefono . "&texto=" . $mensaje);
                // $ch = curl_init();
                // curl_setopt($ch, CURLOPT_URL, $url_holder_sms);
                // curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                // curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
                // $data = curl_exec($ch);
                // curl_close($ch);
                // //Enviar mensaje de texto
                $this->dblink->commit();
                return $resultado;
            }

        }catch(Exception $e){
            $this->dblink->rollBack();
            throw $e;
        }
    }
}