<?php
require __DIR__.'/../datos/Conexion.clase.php';

class Sesion extends Conexion {

    public function iniciarSesionMovil($usuario, $clave, $empresa, $tipo){
        try {
            if($tipo == "F"){
                $sql = "SELECT
                        p.dni_personal,
                        p.apellidos_paternos_personal as pat,
                        p.apellidos_maternos_personal as mat,
                        p.nombres_personal as nomb,
                        u.clave,
                        u.estado,
                        u.codigo_usuario as cod_usuario,
                        c.descripcion_cargo AS cargo,
                        ec.codigo_empresa,
                        ec.nombre_empresa as emp,
                        u.permiso_garita as gar
                    FROM
                        personal_control as p INNER JOIN
                        usuario_control as u ON ( p.dni_personal = u.dni_usuario) INNER JOIN
                        cargo_control as c ON (p.codigo_cargo = c.codigo_cargo) LEFT JOIN
                        usuario_acceso_empresa as uae ON(uae.codigo_usuario = u.codigo_usuario) LEFT join
                        empresa_control as ec on(ec.codigo_empresa = uae.codigo_empresa)
                    WHERE
                        p.email_personal = :p_correo AND
                        ec.estado_empresa = 'A' AND
                        uae.estado = 'A'
					LIMIT 1;";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->bindParam(":p_correo", $usuario);
                $sentencia->execute();
                $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
            }else{
                $sql = "SELECT
                            p.dni_personal,
                            p.apellidos_paternos_personal as pat,
                            p.apellidos_maternos_personal as mat,
                            p.nombres_personal as nomb,
                            u.clave,
                            u.estado,
                            u.codigo_usuario as cod_usuario,
                            c.descripcion_cargo as cargo,
                            coalesce(u.codigo_empresa, '0') as codigo_empresa,
                            e.descripcion_caseta as emp,
                            u.permiso_garita as gar
                        from
                            personal_control p
                            inner join usuario_control u on ( p.dni_personal = u.dni_usuario)
                            inner join cargo_control c on (p.codigo_cargo = c.codigo_cargo)
                            left join caseta_control e on e.codigo_caseta = :p_caseta
                        where
                            p.email_personal = lower(:p_email);";

                $sentencia = $this->dblink->prepare($sql);
                $sentencia->bindParam(":p_email", $usuario);
                $sentencia->bindParam(":p_caseta", $empresa);
                $sentencia->execute();
                $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
            }

            if (!$sentencia->rowCount()) {
                throw new Exception("Datos de inicio de sesión incorrectos.");
            }

            if ($tipo != $resultado["gar"]) {
                throw new Exception("No cuentas con los permisos necesarios para iniciar sesión aquí. \n Comúniquese con el administrador.");
            }

            if ($resultado["estado"] != 'A') {
                throw new Exception("Su cuenta se encuentra inactiva. \n Comuníquese con el administrador.");
            }

            if ($resultado["codigo_empresa"] != $empresa) {
                throw new Exception("Datos de inicio de sesión incorrectos. No cuentas con acceso a esta Garita. \n Comúniquese con el administrador.");
            }

            if ($resultado["clave"] != $clave) {
                throw new Exception("Datos de inicio de sesión incorrectos.");
            }

            $dni_personal = $resultado["dni_personal"];
            unset($resultado["dni_personal"]);
            unset($resultado["clave"]);

            $sql = "SELECT pin_user from personal_control_users where dni_personal = :p_dni_personal";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(":p_dni_personal", $dni_personal);
            $sentencia->execute();

            if ($sentencia->rowCount()) {
                $pin_users = $sentencia->fetchAll(PDO::FETCH_ASSOC);
            } else {
                $pin_users = [];
            }

            $resultado["pines"] = $pin_users;

            return $resultado;
        } catch (Exception $e) {
            throw $e;
        }
    }

    public function obtenerPines($codigo_empresa){
        try{
            $sql = "SELECT
                        p.dni_personal
                    FROM
                        personal_control as p INNER JOIN
                        usuario_control as u ON ( p.dni_personal = u.dni_usuario) INNER JOIN
                        cargo_control as c ON (p.codigo_cargo = c.codigo_cargo) LEFT JOIN
                        usuario_acceso_empresa as uae ON(uae.codigo_usuario = u.codigo_usuario) LEFT join
                        empresa_control as ec on(ec.codigo_empresa = uae.codigo_empresa)
                    WHERE
                        ec.codigo_empresa = :codigo_empresa  AND
                        ec.estado_empresa = 'A' AND
                        uae.estado = 'A';";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(":codigo_empresa", $codigo_empresa);
            $sentencia->execute();
            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
            $dni_personal = $resultado["dni_personal"];

            $sql = "SELECT pin_user from personal_control_users where dni_personal = :p_dni_personal";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(":p_dni_personal", $dni_personal);
            $sentencia->execute();

            if ($sentencia->rowCount()) {
                $pin_users = $sentencia->fetchAll(PDO::FETCH_ASSOC);
            } else {
                $pin_users = [];
            }

            return $pin_users;
        }catch(Exception $e){
            throw $e;
        }
    }
}